package com.ebaiyihui.family.doctor.server.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ebaiyihui.family.doctor.common.vo.cloudHis.*;
import com.ebaiyihui.family.doctor.server.common.constants.ProjProperties;
import com.ebaiyihui.family.doctor.server.service.HisTemplateService;
import com.ebaiyihui.family.doctor.server.util.HttpKit;
import com.ebaiyihui.his.pojo.vo.base.FrontRequest;
import com.ebaiyihui.his.pojo.vo.base.FrontResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


@Service
@Slf4j
public class HisTemplateServiceImpl implements HisTemplateService {

    @Autowired
    private ProjProperties projProperties;


    /**
     * 手动在云his挂号并接诊
     * @param appPointRequestDTO
     * @return
     */


    @Override
    public MakeAnAppointmentRequestVO admissionRegistration(AppPointRequestDTO appPointRequestDTO) {
        String url = projProperties.getAdmissionRegistration();
        FrontRequest<AppPointRequestDTO> request = new FrontRequest<>();
        request.setBody(appPointRequestDTO);
        try {
            log.info("云his=>>新增就诊信息请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse<MakeAnAppointmentRequestVO> frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>新增就诊信息返回值:{}" , JSONObject.toJSONString(frontResponse));
            MakeAnAppointmentRequestVO makeAnAppointmentRequestVO = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    MakeAnAppointmentRequestVO.class);
            log.info("云his=>新增就诊记录返回值:{}" , JSONObject.toJSONString(makeAnAppointmentRequestVO));
            return makeAnAppointmentRequestVO;
        } catch (Exception e) {
            log.error("新增预约信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<String> updateAppointment(AppPointRequestDTO appPointRequestDTO) {
        String url = projProperties.getAdmissionUpdate();
        FrontRequest<AppPointRequestDTO> request = new FrontRequest<>();
        request.setBody(appPointRequestDTO);
        try {
            log.info("云his=>>更新挂号信息请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>更新挂号信息返回值:{}" + JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return null;
            }
            String data = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    String.class);
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("更新挂号信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<String> saveDiagnostic(DiagnosticReqDTO diagnosticReqDTO) {
        String url = projProperties.getUpdateOutpatientMedicalRecords();
        FrontRequest<DiagnosticReqDTO> request = new FrontRequest<>();
        request.setBody(diagnosticReqDTO);
        try {
            log.info("云his=>>保存诊断信息请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>保存诊断信息返回值:{}" + JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return null;
            }
            String data = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    String.class);
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("保存诊断信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<FeeBillCreationVo> createCharge(FeeBillCreationDto feeBillCreationDto) {
        String url = projProperties.getCreateOrderCharge();
        FrontRequest<FeeBillCreationDto> request = new FrontRequest<>();
        request.setBody(feeBillCreationDto);
        try {
            log.info("云his=>>复诊订单预支付信息请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>复诊订单预支付信息返回值:{}" + JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return null;
            }
            FeeBillCreationVo data = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    FeeBillCreationVo.class);
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("复诊订单预支付信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<PayVo> payment(PayDto payDto) {
        String url = projProperties.getPayment();
        FrontRequest<PayDto> request = new FrontRequest<>();
        request.setBody(payDto);
        try {
            log.info("云his=>复诊订单支付信息请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>复诊订单支付信息返回值:{}" + JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return null;
            }
            PayVo data = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    PayVo.class);
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("复诊订单支付信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<String> archiving(ArchivingRequestDTO archivingRequestDTO) {
        String url = projProperties.getArchiving();
        FrontRequest<ArchivingRequestDTO> request = new FrontRequest<>();
        request.setBody(archivingRequestDTO);
        try {
            log.info("云his=>复诊病历归档请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>复诊病历归档信息返回值:{}" + JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return null;
            }
            String data = JSON.toJSONString(frontResponse.getBody());
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("复诊病历归档信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<PayRefundVo> refund(PayRefundDto payRefundDto) {
        String url = projProperties.getRefund();
        FrontRequest<PayRefundDto> request = new FrontRequest<>();
        request.setBody(payRefundDto);
        try {
            log.info("云his=>复诊退款请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>复诊退款信息返回值:{}" + JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return null;
            }
            PayRefundVo data = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    PayRefundVo.class);
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("复诊退款信息异常:{}", e.getMessage());
        }
        return null;
    }

    @Override
    public FrontResponse<OutpatientTypeVo> checkDocAndDeptAndRegFeeInfo(HisDeptAndDocCodeVo hisDeptAndDocCode) {
        String url = projProperties.getCheckDocAndDeptAndRegFeeInfo();
        FrontRequest<HisDeptAndDocCodeVo> request = new FrontRequest<>();
        request.setBody(hisDeptAndDocCode);
        try {
            log.info("云his=>复诊挂号类型医生部门校验请求url:{},param:{}", url, JSON.toJSONString(request));
            String result = HttpKit.jsonPost(url, JSON.toJSONString(request));
            FrontResponse frontResponse = JSONObject.toJavaObject(JSONObject.parseObject(result), FrontResponse.class);
            log.info("云his=>复诊挂号类型医生部门校验返回值:{}" , JSONObject.toJSONString(frontResponse));
            if (!FrontResponse.SUCCESS_CODE.equals(frontResponse.getCode())) {
                return FrontResponse.error(null, FrontResponse.FAILED_CODE, frontResponse.getMessage());
            }
            OutpatientTypeVo data = JSON.parseObject(JSON.toJSONString(frontResponse.getBody()),
                    OutpatientTypeVo.class);
            return FrontResponse.success(null, data);
        } catch (Exception e) {
            log.error("复诊挂号类型医生部门校验异常:{}", e.getMessage());
            return FrontResponse.error(null, FrontResponse.FAILED_CODE, "复诊挂号类型医生部门校验异常");
        }
    }
}
